/**************************************************************************
 *  This file is part of QuteScoop.
 *  Copyright (C) 2007-2008 Martin Domig <martin@domig.net>
 *
 *  QuteScoop is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  QuteScoop is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with QuteScoop.  If not, see <http://www.gnu.org/licenses/>
 **************************************************************************/

#include "Settings.h"
#include "Whazzup.h"

#include <QSettings>
#include <QDebug>

int Settings::downloadInterval() {
	return QSettings().value("download/interval", 5).toInt();
}

void Settings::setDownloadInterval(int value) {
	QSettings().setValue("download/interval", value);
}

bool Settings::downloadOnStartup() {
	return QSettings().value("download/downloadOnStartup", true).toBool();
}

void Settings::setDownloadOnStartup(bool value) {
	QSettings().setValue("download/downloadOnStartup", value);
}

bool Settings::downloadPeriodically() {
	return QSettings().value("download/downloadPeriodically", true).toBool();
}

void Settings::setDownloadPeriodically(bool value) {
	QSettings().setValue("download/downloadPeriodically", value);
}

bool Settings::useSupFile() {
	return QSettings().value("data/useSupFile", false).toBool();
}

void Settings::setUseSupFile(bool value) {
	QSettings().setValue("data/useSupFile", value);
}

int Settings::downloadNetwork() {
	return QSettings().value("download/network", 0).toInt();
}

void Settings::setDownloadNetwork(int i) {
	QSettings().setValue("download/network", i);
}

QString Settings::downloadNetworkName() {
	switch(downloadNetwork()) {
	case 0: return "IVAO"; break;
	case 1: return "VATSIM"; break;
	case 2: return "User Network"; break;
	}
	return "Unknown";
}

QString Settings::userDownloadLocation() {
	return QSettings().value("download/userLocation", "http://www.network.org/status.txt").toString();
}

void Settings::setUserDownloadLocation(const QString& location) {
	QSettings().setValue("download/userLocation", location);
}

bool Settings::checkForUpdates() {
	return QSettings().value("download/checkForUpdates", true).toBool();
}

void Settings::setCheckForUpdates(bool value) {
	QSettings().setValue("download/checkForUpdates", value);
}

bool Settings::sendVersionInformation() {
	return QSettings().value("download/sendVersionInfo", true).toBool();
}

void Settings::setSendVersionInformation(bool value) {
	QSettings().setValue("download/sendVersionInfo", value);
}

QString Settings::updateVersionNumber() {
	return QSettings().value("download/updateVersionNumber").toString();
}

void Settings::setUpdateVersionNumber(const QString& version) {
	QSettings().setValue("download/updateVersionNumber", version);
}

QString Settings::statusLocation() {
	return QSettings().value("download/statusLocation", "http://www.ivao.aero/whazzup/status.txt").toString();
}

void Settings::setStatusLocation(const QString& location) {
	QSettings().setValue("download/statusLocation", location);
	Whazzup::getInstance()->setStatusLocation(location);
}

bool Settings::useProxy() {
	return QSettings().value("proxy/useProxy", false).toBool();
}

void Settings::setUseProxy(bool value) {
	QSettings().setValue("proxy/useProxy", value);
}

QString Settings::proxyServer() {
	return QSettings().value("proxy/server").toString();
}

void Settings::setProxyServer(const QString& server) {
	QSettings().setValue("proxy/server", server);
}

int Settings::proxyPort() {
	return QSettings().value("proxy/port", 8080).toInt();
}

void Settings::setProxyPort(int value) {
	QSettings().setValue("proxy/port", value);
}

QString Settings::proxyUser() {
	return QSettings().value("proxy/user").toString();
}

void Settings::setProxyUser(QString user) {
	QSettings().setValue("proxy/user", user);
}

QString Settings::proxyPassword() {
	return QSettings().value("proxy/password").toString();
}

void Settings::setProxyPassword(QString password) {
	QSettings().setValue("proxy/password", password);
}

void Settings::applyProxySetting(QHttp *http) {
	if(!useProxy() || http == 0)
		return;
	
	QString user = Settings::proxyUser();
	QString pass = Settings::proxyPassword();
	if(user.isEmpty()) user = QString();
	if(pass.isEmpty()) pass = QString();
		
	if(!proxyServer().isEmpty())
		http->setProxy(proxyServer(), proxyPort(), user, pass);
}

int Settings::timelineSeconds() {
	return QSettings().value("display/timelineSeconds", 120).toInt();
}

void Settings::setTimelineSeconds(int value) {
	QSettings().setValue("display/timelineSeconds", value);
}

bool Settings::displaySmoothLines() {
	return QSettings().value("display/smoothLines", true).toBool();
}

void Settings::setDisplaySmoothLines(bool value) {
	QSettings().setValue("display/smoothLines", value);
}

bool Settings::displaySmoothDots() {
	return QSettings().value("display/smoothDots", true).toBool();
}

void Settings::setDisplaySmoothDots(bool value) {
	QSettings().setValue("display/smoothDots", value);
}

int Settings::maxLabels() {
	return QSettings().value("display/maxLabels", 80).toInt();
}

void Settings::setMaxLabels(int maxLabels) {
	QSettings().setValue("display/maxLabels", maxLabels);
}

QString Settings::navdataDirectory() {
	return QSettings().value("database/path").toString();
}

void Settings::setNavdataDirectory(const QString& directory) {
	QSettings().setValue("database/path", directory);
}

int Settings::metarDownloadInterval() {
	return QSettings().value("display/metarInterval", 10).toInt();
}

void Settings::setMetarDownloadInterval(int minutes) {
	QSettings().setValue("download/metarInterval", minutes);
}

QColor Settings::backgroundColor() {
	// the default value is the "Trolltech Purple"
	return QSettings().value("earthSpace/backgroundColor", QColor::fromCmykF(0.39, 0.39, 0.0, 0.0)).value<QColor>();
}

void Settings::setBackgroundColor(const QColor& color) {
	QSettings().setValue("earthSpace/backgroundColor", color);
}

QColor Settings::globeColor() {
	return QSettings().value("earthSpace/globeColor", QColor::fromRgbF(0, 0, 0.2, 1)).value<QColor>();
}

void Settings::setGlobeColor(const QColor& color) {
	QSettings().setValue("earthSpace/globeColor", color);
}

QColor Settings::gridLineColor() {
	return QSettings().value("earthSpace/gridLineColor", QColor::fromRgbF(0.2, 0.2, 0.2, 1)).value<QColor>();
}

void Settings::setGridLineColor(const QColor& color) {
	QSettings().setValue("earthSpace/gridLineColor", color);
}

double Settings::gridLineStrength() {
	return QSettings().value("earthSpace/gridLineStrength", 1).toDouble();
}

void Settings::setGridLineStrength(double strength) {
	QSettings().setValue("earthSpace/gridLineStrength", strength);
}

QColor Settings::countryLineColor() {
	return QSettings().value("earthSpace/countryLineColor", QColor::fromRgbF(0.4, 0.4, 0.4, 1)).value<QColor>();
}

void Settings::setCountryLineColor(const QColor& color) {
	QSettings().setValue("earthSpace/countryLineColor", color);
}

double Settings::countryLineStrength() {
	return QSettings().value("earthSpace/countryLineStrength", 1).toDouble();
}

void Settings::setCountryLineStrength(double strength) {
	QSettings().setValue("earthSpace/countryLineStrength", strength);
}

QColor Settings::coastLineColor() {
	return QSettings().value("earthSpace/coastLineColor", QColor::fromRgbF(0.3, 0.3, 0.3, 1)).value<QColor>();
}

void Settings::setCoastLineColor(const QColor& color) {
	QSettings().setValue("earthSpace/coastLineColor", color);
}

double Settings::coastLineStrength() {
	return QSettings().value("earthSpace/coastLineStrength", 2).toDouble();
}

void Settings::setCoastLineStrength(double strength) {
	QSettings().setValue("earthSpace/coastLineStrength", strength);
}

void Settings::deleteEarthSpaceSettings() {
	QSettings settings;
	settings.beginGroup("earthSpace");
	settings.remove("");
	settings.endGroup();
}

void Settings::deleteFirSettings() {
	QSettings settings;
	settings.beginGroup("firDisplay");
	settings.remove("");
	settings.endGroup();
}

QColor Settings::firBorderLineColor() {
	return QSettings().value("firDisplay/borderLineColor", QColor::fromRgbF(1.0, 0.0, 0.0, 1)).value<QColor>();
}

void Settings::setFirBorderLineColor(const QColor& color) {
	QSettings().setValue("firDisplay/borderLineColor", color);
}

double Settings::firBorderLineStrength() {
	return QSettings().value("firDisplay/borderLineStrength", 2).toDouble();
}

void Settings::setFirBorderLineStrength(double strength) {
	QSettings().setValue("firDisplay/borderLineStrength", strength);
}

QColor Settings::firFontColor() {
	return QSettings().value("firDisplay/fontColor", QColor::fromRgbF(1.0, 0.0, 0.0, 1)).value<QColor>();
}

void Settings::setFirFontColor(const QColor& color) {
	QSettings().setValue("firDisplay/fontColor", color);
}

QColor Settings::firFillColor() {
	return QSettings().value("firDisplay/fillColor", QColor::fromRgbF(0.5, 0.0, 0.0, 1)).value<QColor>();
}

void Settings::setFirFillColor(const QColor& color) {
	QSettings().setValue("firDisplay/fillColor", color);
}

QFont Settings::firFont() {
	QFont defaultFont;
	defaultFont.setBold(true);
	defaultFont.setPixelSize(12);
	QFont result = QSettings().value("firDisplay/font", defaultFont).value<QFont>();
	result.setStyleHint( QFont::SansSerif, QFont::PreferAntialias );
	return result;
}

void Settings::setFirFont(const QFont& font) {
	QSettings().setValue("firDisplay/font", font);
}

void Settings::deleteAirportSettings() {
	QSettings settings;
	settings.beginGroup("airportDisplay");
	settings.remove("");
	settings.endGroup();
}

QColor Settings::airportFontColor() {
	return QSettings().value("airportDisplay/fontColor", QColor::fromRgbF(0.1, 1.0, 0.1, 1)).value<QColor>();
}

void Settings::setAirportFontColor(const QColor& color) {
	QSettings().setValue("airportDisplay/fontColor", color);
}

QColor Settings::airportDotColor() {
	return QSettings().value("airportDisplay/dotColor", QColor::fromRgbF(0.6, 0.6, 0.6, 1)).value<QColor>();
}

void Settings::setAirportDotColor(const QColor& color) {
	QSettings().setValue("airportDisplay/dotColor", color);
}

double Settings::airportDotSize() {
	return QSettings().value("airportDisplay/dotSizer", 0.8).toDouble();
}

void Settings::setAirportDotSize(double value) {
	QSettings().setValue("airportDisplay/dotSizer", value);
}

QFont Settings::airportFont() {
	QFont defaultResult;
	defaultResult.setPixelSize(9);
	QFont result = QSettings().value("airportDisplay/font", defaultResult).value<QFont>();
	result.setStyleHint( QFont::SansSerif, QFont::PreferAntialias );
	return result;
}

void Settings::setAirportFont(const QFont& font) {
	QSettings().setValue("airportDisplay/font", font);
}

QColor Settings::appBorderLineColor() {
	return QSettings().value("airportDisplay/appBorderLineColor", QColor::fromRgbF(0.0, 0.0, 1.0, 1)).value<QColor>();
}

void Settings::setAppBorderLineColor(const QColor& color) {
	QSettings().setValue("airportDisplay/appBorderLineColor", color);
}

double Settings::appBorderLineStrength() {
	return QSettings().value("airportDisplay/appBorderLineStrength", 1.5).toDouble();
}

void Settings::setAppBorderLineStrength(double value) {
	QSettings().setValue("airportDisplay/appBorderLineStrength", value);
}

QColor Settings::appCenterColor() {
	return QSettings().value("airportDisplay/appCenterColor", QColor::fromRgbF(0.0, 0.0, 1.0, 1)).value<QColor>();
}

void Settings::setAppCenterColor(const QColor& color) {
	QSettings().setValue("airportDisplay/appCenterColor", color);
}

QColor Settings::appMarginColor() {
	return QSettings().value("airportDisplay/appMarginColor", QColor::fromRgbF(0.0, 0.0, 0.8, 0.6)).value<QColor>();
}

void Settings::setAppMarginColor(const QColor& color) {
	QSettings().setValue("airportDisplay/appMarginColor", color);
}

QColor Settings::twrMarginColor() {
	return QSettings().value("airportDisplay/twrMarginColor", QColor::fromRgbF(0.6, 0.6, 0.0, 0.6)).value<QColor>();
}

void Settings::setTwrMarginColor(const QColor& color) {
	QSettings().setValue("airportDisplay/twrMarginColor", color);
}

QColor Settings::twrCenterColor() {
	return QSettings().value("airportDisplay/twrCenterColor", QColor::fromRgbF(0.8, 0.8, 0.0, 1.0)).value<QColor>();
}

void Settings::setTwrCenterColor(const QColor& color) {
	QSettings().setValue("airportDisplay/twrCenterColor", color);
}

QColor Settings::gndBorderLineColor() {
	return QSettings().value("airportDisplay/gndBorderLineColor", QColor::fromRgbF(1.0, 0.0, 1.0, 1.0)).value<QColor>();
}

void Settings::setGndBorderLineColor(const QColor& color) {
	QSettings().setValue("airportDisplay/gndBorderLineColor", color);	
}

double Settings::gndBorderLineStrength() {
	return QSettings().value("airportDisplay/gndBorderLineStrength", 1.2).toDouble();
}

void Settings::setGndBorderLineStrength(double value) {
	QSettings().setValue("airportDisplay/gndBorderLineStrength", value);
}

QColor Settings::gndFillColor() {
	return QSettings().value("airportDisplay/gndFillColor", QColor::fromRgbF(0.7, 0.0, 0.7, 0.8)).value<QColor>();
}

void Settings::setGndFillColor(const QColor& color) {
	QSettings().setValue("airportDisplay/gndFillColor", color);
}

void Settings::deleteAircraftSettings() {
	QSettings settings;
	settings.beginGroup("pilotDisplay");
	settings.remove("");
	settings.endGroup();
}

QColor Settings::pilotFontColor() {
	return QSettings().value("pilotDisplay/fontColor", QColor::fromRgbF(1, 1, 1, 1)).value<QColor>();
}

void Settings::setPilotFontColor(const QColor& color) {
	QSettings().setValue("pilotDisplay/fontColor", color);
}

QFont Settings::pilotFont() {
	QFont defaultFont;
	defaultFont.setPixelSize(10);
	return QSettings().value("pilotDisplay/font", defaultFont).value<QFont>();
}

void Settings::setPilotFont(const QFont& font) {
	QSettings().setValue("pilotDisplay/font", font);
}

QColor Settings::pilotDotColor() {
	return QSettings().value("pilotDisplay/dotColor", QColor::fromRgbF(1, 1, 1, 1)).value<QColor>();
}

void Settings::setPilotDotColor(const QColor& color) {
	QSettings().setValue("pilotDisplay/dotColor", color);
}

double Settings::pilotDotSize() {
	return QSettings().value("pilotDisplay/dotSize", 2.5).toDouble();
}

void Settings::setPilotDotSize(double value) {
	QSettings().setValue("pilotDisplay/dotSize", value);
}

QColor Settings::timeLineColor() {
	return QSettings().value("pilotDisplay/timeLineColor", QColor::fromRgbF(0.8, 0.8, 0.8, 0.8)).value<QColor>();
}

void Settings::setTimeLineColor(const QColor& color) {
	QSettings().setValue("pilotDisplay/timeLineColor", color);
}

QColor Settings::trackLineColor() {
	return QSettings().value("pilotDisplay/trackLineColor", QColor::fromRgbF(0.8, 0.8, 0.8, 0.6)).value<QColor>();
}

void Settings::setTrackLineColor(const QColor& color) {
	QSettings().setValue("pilotDisplay/trackLineColor", color);
}

void Settings::setDashedTrackInFront(bool value) {
	QSettings().setValue("pilotDisplay/dashedTrackInFront", value);
}

bool Settings::dashedTrackInFront() {
	return QSettings().value("pilotDisplay/dashedTrackInFront", true).toBool();
}

double Settings::timeLineStrength() {
	return QSettings().value("pilotDisplay/timeLineStrength", 0.8).toDouble();
}

void Settings::setTimeLineStrength(double value) {
	QSettings().setValue("pilotDisplay/timeLineStrength", value);
}

double Settings::trackLineStrength() {
	return QSettings().value("pilotDisplay/trackLineStrength", 2.0).toDouble();
}

void Settings::setTrackLineStrength(double value) {
	QSettings().setValue("pilotDisplay/trackLineStrength", value);
}

void Settings::getRememberedMapPosition(double *xrot, double *yrot, double *zrot, double *zoom) {
	if(xrot == 0 || yrot == 0 || zrot == 0 || zoom == 0)
		return;
	
	*xrot = QSettings().value("defaultMapPosition/xrot", *xrot).toDouble();
	*yrot = QSettings().value("defaultMapPosition/yrot", *yrot).toDouble();
	// ignore zoom. we can't tilt the earth, xy2latlon would fuck up
	*zoom = QSettings().value("defaultMapPosition/zoom", *zoom).toDouble();
}

void Settings::setRememberedMapPosition(double xrot, double yrot, double zrot, double zoom) {
	QSettings().setValue("defaultMapPosition/xrot", xrot);
	QSettings().setValue("defaultMapPosition/yrot", yrot);
	QSettings().setValue("defaultMapPosition/zrot", zrot);
	QSettings().setValue("defaultMapPosition/zoom", zoom);
}

void Settings::saveState(const QByteArray& state) {
	QSettings().setValue("mainWindowState/state", state);
}

QByteArray Settings::getSavedState() {
	return QSettings().value("mainWindowState/state", QByteArray()).toByteArray();
}

void Settings::saveSize(const QSize& size) {
	QSettings().setValue("mainWindowState/size", size);
}

QSize Settings::getSavedSize() {
	return QSettings().value("mainWindowState/size", QSize()).toSize();
}

void Settings::savePosition(const QPoint& pos) {
	QSettings().setValue("mainWindowState/position", pos);
}

QPoint Settings::getSavedPosition() {
	return QSettings().value("mainWindowState/position", QPoint()).toPoint();
}

QStringList Settings::friends() {
	return QSettings().value("friends/friendList", QStringList()).toStringList();
}

void Settings::addFriend(const QString& friendId) {
	QStringList fl = friends();
	if(!fl.contains(friendId))
		fl.append(friendId);
	QSettings().setValue("friends/friendList", fl);
}

void Settings::removeFriend(const QString& friendId) {
	QStringList fl = friends();
	int i = fl.indexOf(friendId);
	if(i >= 0 && i < fl.size())
		fl.removeAt(i);
	QSettings().setValue("friends/friendList", fl);
}

bool Settings::resetOnNextStart() {
	return QSettings().value("general/resetConfiguration", false).toBool();
}

void Settings::setResetOnNextStart(bool value) {
	QSettings().setValue("general/resetConfiguration", value);
}


QString Settings::dataDirectory() {
#ifdef Q_WS_X11
	return QSettings().value("general/dataDirectory", "/usr/share/qutescoop/data/").toString();
#else
	return QSettings().value("general/dataDirectory", "data/").toString();
#endif
}

void Settings::setDataDirectory(const QString& value) {
	QSettings().setValue("general/dataDirectory", value);
}

Settings::VoiceType Settings::voiceType() {
	return (VoiceType) QSettings().value("voice/type", TEAMSPEAK).toInt();
}

void Settings::setVoiceType(Settings::VoiceType type) {
	QSettings().setValue("voice/type", (int)type);
}

QString Settings::voiceCallsign() {
	return QSettings().value("voice/callsign").toString();
}

void Settings::setVoiceCallsign(const QString& value) {
	QSettings().setValue("voice/callsign", value);
}

QString Settings::voiceUser() {
	return QSettings().value("voice/user").toString();
}

void Settings::setVoiceUser(const QString& value) {
	QSettings().setValue("voice/user", value);
}

QString Settings::voicePassword() {
	return QSettings().value("voice/password").toString();
}

void Settings::setVoicePassword(const QString& value) {
	QSettings().setValue("voice/password", value);
}
